call plug#begin()
Plug 'junegunn/goyo.vim'
Plug 'itchyny/lightline.vim'
Plug 'vimwiki/vimwiki'
Plug 'ggandor/leap.nvim'
Plug 'junegunn/fzf', { 'do': { -> fzf#install() } }
Plug 'junegunn/fzf.vim'
Plug 'tpope/vim-commentary'
Plug 'godlygeek/tabular'
Plug 'preservim/vim-markdown'
Plug 'morhetz/gruvbox'
Plug 'dylanaraps/wal.vim'
call plug#end()

" Load leap mappings
lua require('leap').add_default_mappings()

" Customize fzf
let $FZF_DEFAULT_COMMAND='find . \! \( -type d -path ./.git -prune \) \! -type d \! -name ''*.tags'' -printf ''%P\n'''

" Lightline theme
let g:lightline = {
      \ 'colorscheme': 'apprentice',
      \ 'component': {
      \   'lineinfo': '%3l:%-2v%<',
      \ },
      \ }

let g:vimwiki_list = [{'path': '~/vimwiki/', 'syntax': 'markdown', 'ext': '.md'},
                     \ {'path': '~/vimwiki/personal/', 'syntax': 'markdown', 'ext': '.md'},
                     \ {'path': '~/vimwiki/writing/', 'syntax': 'markdown', 'ext': '.md'}]

let g:vimwiki_global_ext = 0

" Sets how many lines of history VIM has to remember
set history=500

" Enable filetype plugins
filetype plugin on
filetype indent on

" Set to auto read when a file is changed from the outside
set autoread
au FocusGained,BufEnter * checktime

" Set 7 lines to the cursor - when moving vertically using j/k
set so=7

" Turn on the Wild menu
set wildmenu

" Height of the command bar
set cmdheight=1

" A buffer becomes hidden when it is abandoned
set hid

" Configure backspace so it acts as it should act
set backspace=eol,start,indent
set whichwrap+=<,>,h,l

" Ignore case when searching
set ignorecase

" When searching try to be smart about cases
set smartcase

" Highlight search results
set hlsearch

" Makes search act like search in modern browsers
set incsearch

" Don't redraw while executing macros (good performance config)
set lazyredraw

" For regular expressions turn magic on
set magic

" Show matching brackets when text indicator is over them
set showmatch

" How many tenths of a second to blink when matching brackets
set mat=2

" Show line number
set number

" Enable syntax highlighting
syntax enable

" Background
set background=dark

" Set utf8 as standard encoding and en_US as the standard language
set encoding=utf8

" Use Unix as the standard file type
set ffs=unix,dos,mac

" Turn backup off, since most stuff is in SVN, git etc. anyway...
set nobackup
set nowb
set noswapfile

" Use spaces instead of tabs
set expandtab

" Be smart when using tabs ;)
set smarttab

" 1 tab == 4 spaces
set shiftwidth=4
set tabstop=4

" Linebreak on 500 characters
set lbr
set tw=500

set ai "Auto indent
set si "Smart indent
set wrap "Wrap lines

" Always show the status line
set laststatus=2

" Set the title
set title

" No automatic commenting on a new line
autocmd FileType * setlocal formatoptions-=c formatoptions-=r formatoptions-=o

" Automatically deletes all trailing whitespace on save
autocmd BufWritePre * %s/\s\+$//e

" Remove --insert-- as there's Limelight
set noshowmode

" Copy and paste between vim and other programs
set clipboard+=unnamedplus

" Vimwiki stuff
set nocompatible

" Make colorschemes work
" set termguicolors
" autocmd vimenter * ++nested colorscheme gruvbox
colorscheme wal

" Keybindings
let mapleader = ";"
nnoremap <space> :Files<CR>

" Transparency
let s:palette = g:lightline#colorscheme#{g:lightline.colorscheme}#palette
let s:palette.normal.middle = [ [ 'NONE', 'NONE', 'NONE', 'NONE' ] ]
let s:palette.inactive.middle = s:palette.normal.middle
let s:palette.tabline.middle = s:palette.normal.middle

"Remove blank line ~
let &fcs='eob: '
